summaryrefslogtreecommitdiffstats
path: root/krecipes/src/dialogs/recipeimportdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'krecipes/src/dialogs/recipeimportdialog.h')
-rw-r--r--krecipes/src/dialogs/recipeimportdialog.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/krecipes/src/dialogs/recipeimportdialog.h b/krecipes/src/dialogs/recipeimportdialog.h
index d41c1b4..7339c65 100644
--- a/krecipes/src/dialogs/recipeimportdialog.h
+++ b/krecipes/src/dialogs/recipeimportdialog.h
@@ -13,9 +13,9 @@
#ifndef RECIPEIMPORTDIALOG_H
#define RECIPEIMPORTDIALOG_H
-#include <qvaluelist.h>
-#include <qmap.h>
-#include <qlistview.h>
+#include <ntqvaluelist.h>
+#include <ntqmap.h>
+#include <ntqlistview.h>
#include <kdialogbase.h>
@@ -23,7 +23,7 @@
class KListView;
-class QListViewItem;
+class TQListViewItem;
class Recipe;
class CustomCheckListItem;
@@ -34,7 +34,7 @@ class CustomCheckListItem;
class RecipeImportDialog : public KDialogBase
{
public:
- RecipeImportDialog( const RecipeList &all_recipes, QWidget *parent = 0 );
+ RecipeImportDialog( const RecipeList &all_recipes, TQWidget *parent = 0 );
~RecipeImportDialog();
RecipeList getSelectedRecipes();
@@ -47,20 +47,20 @@ private:
KListView* kListView;
- QMap<CustomCheckListItem*, RecipeList::const_iterator> *recipe_items;
+ TQMap<CustomCheckListItem*, RecipeList::const_iterator> *recipe_items;
const RecipeList list_copy;
};
/** A specialized QCheckListItem that sets the state of its children to its
* current state.
* @author Jason Kivlighn
*/
-class CustomCheckListItem : public QCheckListItem
+class CustomCheckListItem : public TQCheckListItem
{
public:
- CustomCheckListItem( QListView *parent, const QString &, Type );
- CustomCheckListItem( CustomCheckListItem *parent, const QString &, Type );
- CustomCheckListItem( QCheckListItem *parent, QCheckListItem *after, const QString &, Type );
+ CustomCheckListItem( TQListView *parent, const TQString &, Type );
+ CustomCheckListItem( CustomCheckListItem *parent, const TQString &, Type );
+ CustomCheckListItem( TQCheckListItem *parent, TQCheckListItem *after, const TQString &, Type );
protected:
virtual void stateChange( bool );
@@ -47,20 +47,20 @@ private:
const RecipeList list_copy;
};
-/** A specialized QCheckListItem that sets the state of its children to its
+/** A specialized TQCheckListItem that sets the state of its children to its
* current state.
* @author Jason Kivlighn